@@ -1,6 +1,5 @@
 /*****************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
- *                                                                           *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
  *                                                                           *
  *   This program is free software; you can redistribute it and/or modify    *
  *   it under the terms of the GNU General Public License as published by    *
@@ -13,7 +12,7 @@
  *   GNU General Public License for more details.                            *
  *                                                                           *
  *   You should have received a copy of the GNU General Public License       *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.    *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.   *
  *****************************************************************************/
 
 #ifndef CONFIG_NOTIFICATIONHUB_H
@@ -37,8 +36,13 @@ public:
 class KBIBTEXCONFIG_EXPORT NotificationHub
 {
 public:
+    NotificationHub(const NotificationHub &other) = delete;
+    NotificationHub &operator= (const NotificationHub &other) = delete;
+    ~NotificationHub();
+
     static const int EventAny;
     static const int EventConfigurationChanged;
+    static const int EventBibliographySystemChanged;
     static const int EventUserDefined;
 
     static void registerNotificationListener(NotificationListener *listener, int eventId = NotificationHub::EventAny);
@@ -48,12 +52,11 @@ public:
 
 private:
     class NotificationHubPrivate;
-    NotificationHubPrivate *d;
+    NotificationHubPrivate *const d;
 
-    static NotificationHub *getHub();
+    static NotificationHub &instance();
 
     NotificationHub();
-    ~NotificationHub();
 };
 
 #endif // CONFIG_NOTIFICATIONHUB_H
