@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "findduplicatesui.h"
@@ -28,37 +28,37 @@
 #include <QKeyEvent>
 #include <QSplitter>
 #include <QPointer>
+#include <QStandardPaths>
+#include <QPushButton>
+#include <QAction>
+#include <QDialog>
+#include <QDialogButtonBox>
 
-#include <KPushButton>
-#include <KAction>
-#include <KDialog>
 #include <KActionCollection>
-#include <KLocale>
+#include <KLocalizedString>
 #include <kparts/part.h>
 #include <KMessageBox>
-#include <KDebug>
 #include <KLineEdit>
 
-#include <kdeversion.h>
-
 #include "fileimporterbibtex.h"
 #include "bibtexentries.h"
 #include "radiobuttontreeview.h"
 #include "fileview.h"
-#include "filemodel.h"
+#include "filedelegate.h"
+#include "models/filemodel.h"
 #include "findduplicates.h"
-
-const int FieldNameRole = Qt::UserRole + 101;
-const int UserInputRole = Qt::UserRole + 103;
+#include "logging_gui.h"
 
 /**
  * Model to hold alternative values as visualized in the RadioTreeView
  */
 class AlternativesItemModel : public QAbstractItemModel
 {
+    Q_OBJECT
+
 private:
     /// marker to memorize in an index's internal id that it is a top-level index
-    static const quint32 noParentInternalId;
+    static const quintptr noParentInternalId;
 
     /// parent widget, needed to get font from (for text in italics)
     QTreeView *p;
@@ -68,9 +68,16 @@ private:
 public:
     enum SelectionType {SelectionTypeNone, SelectionTypeRadio, SelectionTypeCheck};
 
+    enum AlternativesItemModelRole {
+        /// Raw, all-lowercase field name
+        FieldNameRole = Qt::UserRole + 101,
+        /// Text used for inline editing of values
+        UserInputRole = Qt::UserRole + 103
+    };
+
     AlternativesItemModel(QTreeView *parent)
-            : QAbstractItemModel(parent), p(parent), currentClique(NULL) {
-        // nothing
+            : QAbstractItemModel(parent), p(parent), currentClique(nullptr) {
+        /// nothing
     }
 
     static SelectionType selectionType(const QString &fieldName) {
@@ -85,23 +92,23 @@ public:
         this->currentClique = currentClique;
     }
 
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const {
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override {
         if (parent == QModelIndex())
             return createIndex(row, column, noParentInternalId);
         else if (parent.parent() == QModelIndex())
-            return createIndex(row, column, parent.row());
+            return createIndex(row, column, static_cast<quintptr>(parent.row()));
         return QModelIndex();
     }
 
-    QModelIndex parent(const QModelIndex &index) const {
+    QModelIndex parent(const QModelIndex &index) const override {
         if (index.internalId() >= noParentInternalId)
             return QModelIndex();
         else
-            return createIndex(index.internalId(), 0, noParentInternalId);
+            return createIndex(static_cast<int>(index.internalId()), 0, noParentInternalId);
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const {
-        if (currentClique == NULL)
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override {
+        if (currentClique == nullptr)
             return 0;
 
         if (parent == QModelIndex()) {
@@ -110,7 +117,7 @@ public:
         } else if (parent.parent() == QModelIndex()) {
             /// first, find the map of alternatives for this chosen field name (see parent)
             QString fieldName = parent.data(FieldNameRole).toString();
-            QList<Value> alt = currentClique->values(fieldName);
+            const auto alt = currentClique->values(fieldName);
             /// second, return number of alternatives for list of alternatives
             /// plus one for an "else" option
             return alt.count() + (fieldName.startsWith('^') || fieldName == Entry::ftKeywords || fieldName == Entry::ftUrl ? 0 : 1);
@@ -119,12 +126,12 @@ public:
         return 0;
     }
 
-    int columnCount(const QModelIndex &) const {
+    int columnCount(const QModelIndex &) const override {
         /// only one column in use
         return 1;
     }
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const {
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override {
         Q_UNUSED(section)
         Q_UNUSED(orientation)
 
@@ -133,23 +140,23 @@ public:
         return QVariant();
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const {
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override {
         if (index.parent() == QModelIndex()) {
             /// top-level elements showing field names like "Title", "Authors", etc
             const QString fieldName = currentClique->fieldList().at(index.row()).toLower();
             switch (role) {
-            case FieldNameRole:
+            case AlternativesItemModelRole::FieldNameRole:
                 /// plain-and-simple field name (all lower case)
                 return fieldName;
             case Qt::ToolTipRole:
             case Qt::DisplayRole:
                 /// nicely formatted field names for visual representation
-                if (fieldName == QLatin1String("^id"))
+                if (fieldName == QStringLiteral("^id"))
                     return i18n("Identifier");
-                else if (fieldName == QLatin1String("^type"))
+                else if (fieldName == QStringLiteral("^type"))
                     return i18n("Type");
                 else
-                    return BibTeXEntries::self()->format(fieldName, KBibTeX::cUpperCamelCase);
+                    return BibTeXEntries::instance().format(fieldName, KBibTeX::cUpperCamelCase);
             case RadioButtonTreeView::IsRadioRole:
                 /// this is not to be a radio widget
                 return QVariant::fromValue(false);
@@ -166,7 +173,7 @@ public:
 
             /// start with determining which list of alternatives actually to use
             QString fieldName = index.parent().data(FieldNameRole).toString();
-            QList<Value> values = currentClique->values(fieldName);
+            const auto &values = currentClique->values(fieldName);
 
             switch (role) {
             case Qt::EditRole:
@@ -174,10 +181,8 @@ public:
             case Qt::DisplayRole:
                 if (index.row() < values.count()) {
                     QString text = PlainTextValue::text(values.at(index.row()));
-                    if (fieldName == QLatin1String("^type")) {
-                        const BibTeXEntries *be = BibTeXEntries::self();
-                        text = be->format(text, KBibTeX::cUpperCamelCase);
-                    }
+                    if (fieldName == QStringLiteral("^type"))
+                        text = BibTeXEntries::instance().format(text, KBibTeX::cUpperCamelCase);
 
                     /// textual representation of the alternative's value
                     return text;
@@ -196,9 +201,9 @@ public:
                 if (selectionType(fieldName) != SelectionTypeCheck)
                     return QVariant();
 
-                QList<Value> chosenValues = currentClique->chosenValues(fieldName);
+                const auto chosenValues = currentClique->chosenValues(fieldName);
                 QString text = PlainTextValue::text(values.at(index.row()));
-                foreach (const Value &value, chosenValues) {
+                for (const Value &value : chosenValues) {
                     if (PlainTextValue::text(value) == text)
                         return Qt::Checked;
                 }
@@ -229,13 +234,13 @@ public:
         return QVariant();
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int role = RadioButtonTreeView::RadioSelectedRole) {
+    bool setData(const QModelIndex &index, const QVariant &value, int role = RadioButtonTreeView::RadioSelectedRole) override {
         if (index.parent() != QModelIndex()) {
             bool isInt;
             int checkState = value.toInt(&isInt);
 
             const QString fieldName = index.parent().data(FieldNameRole).toString();
-            QList<Value> &values = currentClique->values(fieldName);
+            auto values = currentClique->values(fieldName);
 
             if (role == RadioButtonTreeView::RadioSelectedRole && value.canConvert<bool>() && value.toBool() == true && selectionType(fieldName) == SelectionTypeRadio) {
                 /// start with determining which list of alternatives actually to use
@@ -289,11 +294,12 @@ public:
                             else {
                                 QSharedPointer<Keyword> kw = old.first().dynamicCast<Keyword>();
                                 if (!kw.isNull()) {
-                                    QList<QSharedPointer<Keyword> > keywordList = FileImporterBibTeX::splitKeywords(text);
-                                    for (QList<QSharedPointer<Keyword> >::ConstIterator it = keywordList.constBegin(); it != keywordList.constEnd(); ++it)
-                                        v.append(*it);
+                                    const QList<QSharedPointer<Keyword> > keywordList = FileImporterBibTeX::splitKeywords(text);
+                                    v.reserve(keywordList.size());
+                                    for (const auto &keyword : keywordList)
+                                        v.append(keyword);
                                 } else {
-                                    kDebug() << "Not know how to set this text:" << text;
+                                    qCDebug(LOG_KBIBTEX_GUI) << "Not know how to set this text:" << text;
                                 }
                             }
                         }
@@ -313,19 +319,19 @@ public:
         return false;
     }
 
-    bool hasChildren(const QModelIndex &parent = QModelIndex()) const {
+    bool hasChildren(const QModelIndex &parent = QModelIndex()) const override {
         /// depth-two tree
         return parent == QModelIndex() || parent.parent() == QModelIndex();
     }
 
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const {
+    Qt::ItemFlags flags(const QModelIndex &index) const override {
         Qt::ItemFlags f = QAbstractItemModel::flags(index);
         if (index.parent() != QModelIndex()) {
             QString fieldName = index.parent().data(FieldNameRole).toString();
             if (selectionType(fieldName) == SelectionTypeCheck)
                 f |= Qt::ItemIsUserCheckable;
 
-            QList<Value> values = currentClique->values(fieldName);
+            const auto values = currentClique->values(fieldName);
             if (index.row() < values.count())
                 f |= Qt::ItemIsEditable;
         }
@@ -333,7 +339,7 @@ public:
     }
 };
 
-const quint32 AlternativesItemModel::noParentInternalId = 0xffffff;
+const quintptr AlternativesItemModel::noParentInternalId = std::numeric_limits<quintptr>::max();
 
 
 /**
@@ -342,40 +348,42 @@ const quint32 AlternativesItemModel::noParentInternalId = 0xffffff;
  */
 class AlternativesItemDelegate: public RadioButtonItemDelegate
 {
+    Q_OBJECT
+
 public:
     AlternativesItemDelegate(QObject *p)
             : RadioButtonItemDelegate(p) {
-        // nothing
+        /// nothing
     }
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const {
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const override {
         if (index.parent() != QModelIndex()) {
             /// Only second-level indices in the model can be edited
             /// (those are the actual values).
             /// Use a plain, border-less KLineEdit.
             KLineEdit *lineEdit = new KLineEdit(parent);
-            lineEdit->setStyleSheet(QLatin1String("border: none;"));
+            lineEdit->setStyleSheet(QStringLiteral("border: none;"));
             return lineEdit;
         }
-        return NULL;
+        return nullptr;
     }
 
-    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const {
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override {
         if (KLineEdit *lineEdit = qobject_cast<KLineEdit *>(editor)) {
             /// Set line edit's default value to string fetched from model
             lineEdit->setText(index.data(Qt::EditRole).toString());
         }
     }
 
-    virtual void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const {
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override {
         if (KLineEdit *lineEdit = qobject_cast<KLineEdit *>(editor)) {
             /// Set user-entered text to model (and underlying value)
-            model->setData(index, lineEdit->text(), UserInputRole);
+            model->setData(index, lineEdit->text(), AlternativesItemModel::UserInputRole);
 
             /// Ensure that the edited value is checked if it is
             /// a checkbox-checkable value, or gets a "dot" in its
             /// radio button if it is radio-checkable.
-            const QString fieldName = index.parent().data(FieldNameRole).toString();
+            const QString fieldName = index.parent().data(AlternativesItemModel::FieldNameRole).toString();
             if (AlternativesItemModel::selectionType(fieldName) == AlternativesItemModel::SelectionTypeCheck)
                 model->setData(index, Qt::Checked, Qt::CheckStateRole);
             else if (AlternativesItemModel::selectionType(fieldName) == AlternativesItemModel::SelectionTypeRadio)
@@ -383,7 +391,7 @@ public:
         }
     }
 
-    virtual void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &) const {
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &) const override {
         QRect rect = option.rect;
 
         // TODO better placement of editing widget?
@@ -398,22 +406,24 @@ public:
 
 class CheckableFileModel : public FileModel
 {
+    Q_OBJECT
+
 private:
-    QList<EntryClique *> cl;
+    QVector<EntryClique *> cl;
     int currentClique;
     QTreeView *tv;
 
 public:
-    CheckableFileModel(QList<EntryClique *> &cliqueList, QTreeView *treeView, QObject *parent = NULL)
+    CheckableFileModel(QVector<EntryClique *> &cliqueList, QTreeView *treeView, QObject *parent = nullptr)
             : FileModel(parent), cl(cliqueList), currentClique(0), tv(treeView) {
-        // nothing
+        /// nothing
     }
 
     void setCurrentClique(EntryClique *currentClique) {
         this->currentClique = cl.indexOf(currentClique);
     }
 
-    virtual QVariant data(const QModelIndex &index, int role) const {
+    QVariant data(const QModelIndex &index, int role) const override {
         if (role == Qt::CheckStateRole && index.column() == 1) {
             QSharedPointer<Entry> entry = element(index.row()).dynamicCast<Entry>();
             Q_ASSERT_X(!entry.isNull(), "CheckableFileModel::data", "entry is NULL");
@@ -427,7 +437,7 @@ public:
         return FileModel::data(index, role);
     }
 
-    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) {
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override {
         bool ok;
         int checkState = value.toInt(&ok);
         Q_ASSERT_X(ok, "CheckableFileModel::setData", QString("Could not convert value " + value.toString()).toLatin1());
@@ -450,7 +460,7 @@ public:
         return false;
     }
 
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const {
+    Qt::ItemFlags flags(const QModelIndex &index) const override {
         Qt::ItemFlags f = FileModel::flags(index);
         if (index.column() == 1)
             f |= Qt::ItemIsUserCheckable;
@@ -461,33 +471,35 @@ public:
 
 class FilterIdFileModel : public QSortFilterProxyModel
 {
+    Q_OBJECT
+
 private:
     CheckableFileModel *internalModel;
     EntryClique *currentClique;
 
 public:
-    FilterIdFileModel(QObject *parent = NULL)
-            : QSortFilterProxyModel(parent), internalModel(NULL), currentClique(NULL) {
-        // nothing
+    FilterIdFileModel(QObject *parent = nullptr)
+            : QSortFilterProxyModel(parent), internalModel(nullptr), currentClique(nullptr) {
+        /// nothing
     }
 
     void setCurrentClique(EntryClique *currentClique) {
-        Q_ASSERT_X(internalModel != NULL, "FilterIdFileModel::setCurrentClique(EntryClique *currentClique)", "internalModel is NULL");
+        Q_ASSERT_X(internalModel != nullptr, "FilterIdFileModel::setCurrentClique(EntryClique *currentClique)", "internalModel is NULL");
         internalModel->setCurrentClique(currentClique);
         this->currentClique = currentClique;
         invalidate();
     }
 
-    void setSourceModel(QAbstractItemModel *model) {
+    void setSourceModel(QAbstractItemModel *model) override {
         QSortFilterProxyModel::setSourceModel(model);
         internalModel = dynamic_cast<CheckableFileModel *>(model);
-        Q_ASSERT_X(internalModel != NULL, "FilterIdFileModel::setSourceModel(QAbstractItemModel *model)", "internalModel is NULL");
+        Q_ASSERT_X(internalModel != nullptr, "FilterIdFileModel::setSourceModel(QAbstractItemModel *model)", "internalModel is NULL");
     }
 
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const {
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override {
         Q_UNUSED(source_parent)
 
-        if (internalModel != NULL && currentClique != NULL) {
+        if (internalModel != nullptr && currentClique != nullptr) {
             QSharedPointer<Entry> entry = internalModel->element(source_row).dynamicCast<Entry>();
             if (!entry.isNull()) {
                 QList<QSharedPointer<Entry> > entryList = currentClique->entryList();
@@ -507,7 +519,7 @@ private:
 public:
     File *file;
     FileView *editor;
-    KPushButton *buttonNext, *buttonPrev;
+    QPushButton *buttonNext, *buttonPrev;
     QLabel *labelWhichClique;
     static const char *whichCliqueText;
 
@@ -519,9 +531,9 @@ public:
     AlternativesItemDelegate *alternativesItemDelegate;
 
     int currentClique;
-    QList<EntryClique *> &cl;
+    QVector<EntryClique *> &cl;
 
-    MergeWidgetPrivate(MergeWidget *parent, File *bibTeXFile, QList<EntryClique *> &cliqueList)
+    MergeWidgetPrivate(MergeWidget *parent, File *bibTeXFile, QVector<EntryClique *> &cliqueList)
             : p(parent), file(bibTeXFile), currentClique(0), cl(cliqueList) {
         setupGUI();
     }
@@ -538,7 +550,7 @@ public:
         QSplitter *splitter = new QSplitter(Qt::Vertical, p);
         layout->addWidget(splitter);
 
-        editor = new FileView(QLatin1String("MergeWidget"), splitter);
+        editor = new FileView(QStringLiteral("MergeWidget"), splitter);
         editor->setItemDelegate(new FileDelegate(editor));
         editor->setReadOnly(true);
 
@@ -552,9 +564,9 @@ public:
         containerLayout->addStretch(10);
         labelWhichClique = new QLabel(p);
         containerLayout->addWidget(labelWhichClique);
-        buttonPrev = new KPushButton(KIcon("go-previous"), i18n("Previous Clique"), p);
+        buttonPrev = new QPushButton(QIcon::fromTheme(QStringLiteral("go-previous")), i18n("Previous Clique"), p);
         containerLayout->addWidget(buttonPrev, 1);
-        buttonNext = new KPushButton(KIcon("go-next"), i18n("Next Clique"), p);
+        buttonNext = new QPushButton(QIcon::fromTheme(QStringLiteral("go-next")), i18n("Next Clique"), p);
         containerLayout->addWidget(buttonNext, 1);
 
         filterModel = new FilterIdFileModel(p);
@@ -564,10 +576,10 @@ public:
 
         showCurrentClique();
 
-        connect(buttonPrev, SIGNAL(clicked()), p, SLOT(previousClique()));
-        connect(buttonNext, SIGNAL(clicked()), p, SLOT(nextClique()));
+        connect(buttonPrev, &QPushButton::clicked, p, &MergeWidget::previousClique);
+        connect(buttonNext, &QPushButton::clicked, p, &MergeWidget::nextClique);
 
-        connect(editor, SIGNAL(doubleClicked(QModelIndex)), editor, SLOT(viewCurrentElement()));
+        connect(editor, &FileView::doubleClicked, editor, &FileView::viewCurrentElement);
     }
 
     void showCurrentClique() {
@@ -590,7 +602,7 @@ public:
 
 const char *MergeWidget::MergeWidgetPrivate::whichCliqueText = "Showing clique %1 of %2.";
 
-MergeWidget::MergeWidget(File *file, QList<EntryClique *> &cliqueList, QWidget *parent)
+MergeWidget::MergeWidget(File *file, QVector<EntryClique *> &cliqueList, QWidget *parent)
         : QWidget(parent), d(new MergeWidgetPrivate(this, file, cliqueList))
 {
     /// nothing
@@ -620,25 +632,22 @@ void MergeWidget::nextClique()
 
 class FindDuplicatesUI::FindDuplicatesUIPrivate
 {
-private:
-    // UNUSED FindDuplicatesUI *p;
-
 public:
     KParts::Part *part;
     FileView *view;
 
-    FindDuplicatesUIPrivate(FindDuplicatesUI */* UNUSED parent*/, KParts::Part *kpart, FileView *fileView)
-        : /* UNUSED p(parent),*/ part(kpart), view(fileView) {
-        /// nothing
+    FindDuplicatesUIPrivate(FindDuplicatesUI *parent, KParts::Part *kpart, FileView *fileView)
+            : part(kpart), view(fileView) {
+        Q_UNUSED(parent)
     }
 };
 
 FindDuplicatesUI::FindDuplicatesUI(KParts::Part *part, FileView *fileView)
         : QObject(), d(new FindDuplicatesUIPrivate(this, part, fileView))
 {
-    KAction *newAction = new KAction(KIcon("tab-duplicate"), i18n("Find Duplicates"), this);
-    part->actionCollection()->addAction(QLatin1String("findduplicates"), newAction);
-    connect(newAction, SIGNAL(triggered()), this, SLOT(startDuplicatesSearch()));
+    QAction *newAction = new QAction(QIcon::fromTheme(QStringLiteral("tab-duplicate")), i18n("Find Duplicates"), this);
+    part->actionCollection()->addAction(QStringLiteral("findduplicates"), newAction);
+    connect(newAction, &QAction::triggered, this, &FindDuplicatesUI::startDuplicatesSearch);
 }
 
 FindDuplicatesUI::~FindDuplicatesUI()
@@ -654,9 +663,12 @@ void FindDuplicatesUI::startDuplicatesSearch()
     //if (!ok) sensitivity = 4000;
     int sensitivity = 4000;
 
+    FileModel *model = d->view->fileModel();
+    if (model == nullptr) return;
+
     /// Full file, used to remove merged elements from
     /// Stays the same even when merging is restricted to selected elements
-    File *originalFile = d->view->fileModel()->bibliographyFile();
+    File *originalFile = model->bibliographyFile();
     /// File to be used to find duplicate in,
     /// may be only a subset of the original one if selection is used
     File *workingSetFile = originalFile;
@@ -667,18 +679,17 @@ void FindDuplicatesUI::startDuplicatesSearch()
     if (selectedRowsCount > 1 && selectedRowsCount < d->view->sortFilterProxyModel()->sourceModel()->rowCount() && KMessageBox::questionYesNo(d->part->widget(), i18n("Multiple elements are selected. Do you want to search for duplicates only within the selection or in the whole document?"), i18n("Search only in selection?"), KGuiItem(i18n("Only in selection")), KGuiItem(i18n("Whole document"))) == KMessageBox::Yes) {
         /// Yes, do only search for duplicates within selection, so copy all
         /// selected elements to a temporary new File object
-        QModelIndexList mil = d->view->selectionModel()->selectedRows();
         workingSetFile = new File();
-        for (QModelIndexList::ConstIterator it = mil.constBegin(); it != mil.constEnd(); ++it) {
-            workingSetFile->append(d->view->fileModel()->element(d->view->sortFilterProxyModel()->mapToSource(*it).row()));
-        }
+        const QModelIndexList mil = d->view->selectionModel()->selectedRows();
+        for (const QModelIndex &index : mil)
+            workingSetFile->append(model->element(d->view->sortFilterProxyModel()->mapToSource(index).row()));
     }
 
     /// Actual duplicate finder, can be given a widget that will be the
     /// parent of a progress bar window and sensitivity value when to
     /// recognize two entries as being duplicates of each other
     FindDuplicates fd(d->part->widget(), sensitivity);
-    QList<EntryClique *> cliques;
+    QVector<EntryClique *> cliques;
     bool gotCanceled = fd.findDuplicateEntries(workingSetFile, cliques);
     if (gotCanceled) {
         /// Duplicate search was cancelled, e.g. by pressing the Cancel
@@ -694,16 +705,23 @@ void FindDuplicatesUI::startDuplicatesSearch()
 
         /// Why is a QPointer used here you may wonder? Check here in case the link still works:
         ///   https://blogs.kde.org/2009/03/26/how-crash-almost-every-qtkde-application-and-how-fix-it-0
-        QPointer<KDialog> dlg = new KDialog(d->part->widget());
-        MergeWidget *mw = new MergeWidget(d->view->fileModel()->bibliographyFile(), cliques, dlg);
-        dlg->setMainWidget(mw);
+        QPointer<QDialog> dlg = new QDialog(d->part->widget());
+        dlg->setWindowTitle(i18n("Merge Duplicates"));
+        MergeWidget *mw = new MergeWidget(workingSetFile, cliques, dlg);
+        mw->layout()->setMargin(0);
+        QBoxLayout *layout = new QVBoxLayout(dlg);
+        layout->addWidget(mw);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, dlg);
+        layout->addWidget(buttonBox);
 
-        if (dlg->exec() == QDialog::Accepted && MergeDuplicates::mergeDuplicateEntries(cliques, originalFile)) {
+        connect(buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, dlg.data(), &QDialog::accept);
+        connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, dlg.data(), &QDialog::reject);
+
+        if (dlg->exec() == QDialog::Accepted && MergeDuplicates::mergeDuplicateEntries(cliques, d->view->fileModel())) {
             /// If the user made selections on what to merge how
             /// AND the requested changes could be applied on the
             /// 'original' file (not the working set file), then
             /// notify the world that things have changed
-            d->view->fileModel()->reset();
             d->view->externalModification();
         }
 
@@ -718,3 +736,5 @@ void FindDuplicatesUI::startDuplicatesSearch()
 
     if (workingSetFile != originalFile) delete workingSetFile;
 }
+
+#include "findduplicatesui.moc"
