@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "fileexporterbibtexoutput.h"
@@ -24,47 +24,44 @@
 #include <QUrl>
 #include <QTextStream>
 
-#include <KDebug>
-#include <KLocale>
-
 #include "element.h"
 #include "entry.h"
 #include "fileexporterbibtex.h"
-#include "kbibtexnamespace.h"
+#include "kbibtex.h"
+#include "logging_io.h"
 
-FileExporterBibTeXOutput::FileExporterBibTeXOutput(OutputType outputType)
-        : FileExporterToolchain(), m_outputType(outputType), m_latexLanguage("english"), m_latexBibStyle("plain")
+FileExporterBibTeXOutput::FileExporterBibTeXOutput(OutputType outputType, QObject *parent)
+        : FileExporterToolchain(parent), m_outputType(outputType), m_latexLanguage(QStringLiteral("english")), m_latexBibStyle(QStringLiteral("plain"))
 {
-    m_fileBasename = QLatin1String("bibtex-to-output");
-    m_fileStem = tempDir.name() + QDir::separator() + m_fileBasename;
+    m_fileBasename = QStringLiteral("bibtex-to-output");
+    m_fileStem = tempDir.path() + QDir::separator() + m_fileBasename;
 }
 
 FileExporterBibTeXOutput::~FileExporterBibTeXOutput()
 {
-    // nothing
+    /// nothing
 }
 
 void FileExporterBibTeXOutput::reloadConfig()
 {
-    // nothing
+    /// nothing
 }
 
 bool FileExporterBibTeXOutput::save(QIODevice *ioDevice, const File *bibtexfile, QStringList *errorLog)
 {
     if (!ioDevice->isWritable() && !ioDevice->open(QIODevice::WriteOnly)) {
-        kDebug() << "Output device not writable";
+        qCWarning(LOG_KBIBTEX_IO) << "Output device not writable";
         return false;
     }
 
     bool result = false;
 
-    QBuffer buffer(this);
-    if (buffer.open(QIODevice::WriteOnly)) {
-        FileExporterBibTeX *bibtexExporter = new FileExporterBibTeX();
-        bibtexExporter->setEncoding(QLatin1String("utf-8"));
-        result = bibtexExporter->save(&buffer, bibtexfile, errorLog);
-        buffer.close();
-        delete bibtexExporter;
+    QFile bibTeXFile(m_fileStem + KBibTeX::extensionBibTeX);
+    if (bibTeXFile.open(QIODevice::WriteOnly)) {
+        FileExporterBibTeX bibtexExporter(this);
+        bibtexExporter.setEncoding(QStringLiteral("utf-8"));
+        result = bibtexExporter.save(&bibTeXFile, bibtexfile, errorLog);
+        bibTeXFile.close();
     }
 
     if (result)
@@ -80,19 +77,18 @@ bool FileExporterBibTeXOutput::save(QIODevice *ioDevice, const File *bibtexfile,
 bool FileExporterBibTeXOutput::save(QIODevice *ioDevice, const QSharedPointer<const Element> element, const File *bibtexfile, QStringList *errorLog)
 {
     if (!ioDevice->isWritable() && !ioDevice->open(QIODevice::WriteOnly)) {
-        kDebug() << "Output device not writable";
+        qCWarning(LOG_KBIBTEX_IO) << "Output device not writable";
         return false;
     }
 
     bool result = false;
 
-    QBuffer buffer(this);
-    if (buffer.open(QIODevice::WriteOnly)) {
-        FileExporterBibTeX *bibtexExporter = new FileExporterBibTeX();
-        bibtexExporter->setEncoding(QLatin1String("utf-8"));
-        result = bibtexExporter->save(&buffer, element, bibtexfile, errorLog);
-        buffer.close();
-        delete bibtexExporter;
+    QFile bibTeXFile(m_fileStem + KBibTeX::extensionBibTeX);
+    if (bibTeXFile.open(QIODevice::WriteOnly)) {
+        FileExporterBibTeX bibtexExporter(this);
+        bibtexExporter.setEncoding(QStringLiteral("utf-8"));
+        result = bibtexExporter.save(&bibTeXFile, element, bibtexfile, errorLog);
+        bibTeXFile.close();
     }
 
     if (result)
@@ -117,12 +113,12 @@ void FileExporterBibTeXOutput::setLaTeXBibliographyStyle(const QString &bibStyle
 
 bool FileExporterBibTeXOutput::generateOutput(QStringList *errorLog)
 {
-    QStringList cmdLines = QStringList() << QLatin1String("pdflatex -halt-on-error ") + m_fileBasename + KBibTeX::extensionTeX << QLatin1String("bibtex ") + m_fileBasename + KBibTeX::extensionAux;
+    QStringList cmdLines {QStringLiteral("pdflatex -halt-on-error ") + m_fileBasename + KBibTeX::extensionTeX, QStringLiteral("bibtex ") + m_fileBasename + KBibTeX::extensionAux};
 
     if (writeLatexFile(m_fileStem + KBibTeX::extensionTeX) && runProcesses(cmdLines, errorLog))
         return true;
     else {
-        kWarning() << "Generating BibTeX output failed";
+        qCWarning(LOG_KBIBTEX_IO) << "Generating BibTeX output failed";
         return false;
     }
 }
@@ -136,18 +132,18 @@ bool FileExporterBibTeXOutput::writeLatexFile(const QString &filename)
         ts << "\\documentclass{article}\n";
         ts << "\\usepackage[T1]{fontenc}\n";
         ts << "\\usepackage[utf8]{inputenc}\n";
-        if (kpsewhich("babel.sty"))
+        if (kpsewhich(QStringLiteral("babel.sty")))
             ts << "\\usepackage[" << m_latexLanguage << "]{babel}\n";
-        if (kpsewhich("hyperref.sty"))
+        if (kpsewhich(QStringLiteral("hyperref.sty")))
             ts << "\\usepackage[pdfproducer={KBibTeX: https://userbase.kde.org/KBibTeX},pdftex]{hyperref}\n";
-        else if (kpsewhich("url.sty"))
+        else if (kpsewhich(QStringLiteral("url.sty")))
             ts << "\\usepackage{url}\n";
-        if (m_latexBibStyle.startsWith(QLatin1String("apacite")) && kpsewhich("apacite.sty"))
+        if (m_latexBibStyle.startsWith(QStringLiteral("apacite")) && kpsewhich(QStringLiteral("apacite.sty")))
             ts << "\\usepackage[bibnewpage]{apacite}\n";
         ts << "\\bibliographystyle{" << m_latexBibStyle << "}\n";
         ts << "\\begin{document}\n";
         ts << "\\nocite{*}\n";
-        ts << QLatin1String("\\bibliography{") + m_fileBasename + QLatin1String("}\n");
+        ts << QStringLiteral("\\bibliography{") + m_fileBasename + QStringLiteral("}\n");
         ts << "\\end{document}\n";
         latexFile.close();
         return true;
