@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,6 +22,7 @@
 #include <QDir>
 #include <QTimer>
 #include <QStandardPaths>
+#include <QRegularExpression>
 #ifdef HAVE_QTWIDGETS
 #include <QListWidgetItem>
 #include <QDBusConnection>
@@ -71,18 +72,19 @@ QStringList OnlineSearchQueryFormAbstract::authorLastNames(const Entry &entry)
 #endif // HAVE_QTWIDGETS
 
 OnlineSearchAbstract::OnlineSearchAbstract(QObject *parent)
-    : QObject(parent), m_hasBeenCanceled(false), numSteps(0), curStep(0), m_previousBusyState(false), m_delayedStoppedSearchReturnCode(0)
+        : QObject(parent), m_hasBeenCanceled(false), numSteps(0), curStep(0), m_previousBusyState(false), m_delayedStoppedSearchReturnCode(0)
 {
     m_parent = parent;
 }
 
+#ifdef HAVE_QTWIDGETS
 QIcon OnlineSearchAbstract::icon(QListWidgetItem *listWidgetItem)
 {
-    static const QRegExp invalidChars(QStringLiteral("[^-a-z0-9_]"), Qt::CaseInsensitive);
+    static const QRegularExpression invalidChars(QStringLiteral("[^-a-z0-9_]"), QRegularExpression::CaseInsensitiveOption);
     const QString cacheDirectory = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/favicons/");
     QDir().mkpath(cacheDirectory);
     const QString fileNameStem = cacheDirectory + QString(favIconUrl()).remove(invalidChars);
-    const QStringList fileNameExtensions = QStringList() << QStringLiteral(".ico") << QStringLiteral(".png") << QString();
+    const QStringList fileNameExtensions {QStringLiteral(".ico"), QStringLiteral(".png"), QString()};
 
     for (const QString &extension : fileNameExtensions) {
         const QString fileName = fileNameStem + extension;
@@ -99,7 +101,6 @@ QIcon OnlineSearchAbstract::icon(QListWidgetItem *listWidgetItem)
     return QIcon::fromTheme(QStringLiteral("applications-internet"));
 }
 
-#ifdef HAVE_QTWIDGETS
 OnlineSearchQueryFormAbstract *OnlineSearchAbstract::customWidget(QWidget *) {
     return nullptr;
 }
@@ -114,7 +115,7 @@ void OnlineSearchAbstract::startSearchFromForm()
 
 QString OnlineSearchAbstract::name()
 {
-    static const QRegExp invalidChars("[^-a-z0-9]", Qt::CaseInsensitive);
+    static const QRegularExpression invalidChars(QStringLiteral("[^-a-z0-9]"), QRegularExpression::CaseInsensitiveOption);
     if (m_name.isEmpty())
         m_name = label().remove(invalidChars);
     return m_name;
@@ -160,6 +161,9 @@ bool OnlineSearchAbstract::handleErrors(QNetworkReply *reply)
 
 bool OnlineSearchAbstract::handleErrors(QNetworkReply *reply, QUrl &newUrl)
 {
+    /// The URL to be shown or logged shall not contain any API key
+    const QUrl urlToShow = InternalNetworkAccessManager::removeApiKey(reply->url());
+
     newUrl = QUrl();
     if (m_hasBeenCanceled) {
         stopSearch(resultCancelled);
@@ -167,7 +171,20 @@ bool OnlineSearchAbstract::handleErrors(QNetworkReply *reply, QUrl &newUrl)
     } else if (reply->error() != QNetworkReply::NoError) {
         m_hasBeenCanceled = true;
         const QString errorString = reply->errorString();
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "Search using" << label() << "failed (error code" << reply->error() << "(" << errorString << "), HTTP code" << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt() << ":" << reply->attribute(QNetworkRequest::HttpReasonPhraseAttribute).toByteArray() << ")";
+        qCWarning(LOG_KBIBTEX_NETWORKING) << "Search using" << label() << "failed (error code" << reply->error() << "," << errorString << "), HTTP code" << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt() << ":" << reply->attribute(QNetworkRequest::HttpReasonPhraseAttribute).toByteArray() << ") for URL" << urlToShow.toDisplayString();
+        const QNetworkRequest &request = reply->request();
+        /// Dump all HTTP headers that were sent with the original request (except for API keys)
+        const QList<QByteArray> rawHeadersSent = request.rawHeaderList();
+        for (const QByteArray &rawHeaderName : rawHeadersSent) {
+            if (rawHeaderName.toLower().contains("apikey") || rawHeaderName.toLower().contains("api-key")) continue; ///< skip dumping header values containing an API key
+            qCDebug(LOG_KBIBTEX_NETWORKING) << "SENT " << rawHeaderName << ":" << request.rawHeader(rawHeaderName);
+        }
+        /// Dump all HTTP headers that were received
+        const QList<QByteArray> rawHeadersReceived = reply->rawHeaderList();
+        for (const QByteArray &rawHeaderName : rawHeadersReceived) {
+            if (rawHeaderName.toLower().contains("apikey") || rawHeaderName.toLower().contains("api-key")) continue; ///< skip dumping header values containing an API key
+            qCDebug(LOG_KBIBTEX_NETWORKING) << "RECVD " << rawHeaderName << ":" << reply->rawHeader(rawHeaderName);
+        }
 #ifdef HAVE_KF5
         sendVisualNotification(errorString.isEmpty() ? i18n("Searching '%1' failed for unknown reason.", label()) : i18n("Searching '%1' failed with error message:\n\n%2", label(), errorString), label(), QStringLiteral("kbibtex"), 7 * 1000);
 #endif // HAVE_KF5
@@ -191,11 +208,61 @@ bool OnlineSearchAbstract::handleErrors(QNetworkReply *reply, QUrl &newUrl)
     if (reply->attribute(QNetworkRequest::RedirectionTargetAttribute).isValid()) {
         newUrl = reply->url().resolved(reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl());
     } else if (reply->size() == 0)
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "Search using" << label() << "on url" << reply->url().toDisplayString() << "returned no data";
+        qCWarning(LOG_KBIBTEX_NETWORKING) << "Search using" << label() << "on url" << urlToShow.toDisplayString() << "returned no data";
 
     return true;
 }
 
+QString OnlineSearchAbstract::htmlAttribute(const QString &htmlCode, const int startPos, const QString &attribute) const
+{
+    const int endPos = htmlCode.indexOf(QLatin1Char('>'), startPos);
+    if (endPos < 0) return QString(); ///< no closing angle bracket found
+
+    const QString attributePattern = QString(QStringLiteral(" %1=")).arg(attribute);
+    const int attributePatternPos = htmlCode.indexOf(attributePattern, startPos, Qt::CaseInsensitive);
+    if (attributePatternPos < 0 || attributePatternPos > endPos) return QString(); ///< attribute not found within limits
+
+    const int attributePatternLen = attributePattern.length();
+    const int openingQuotationMarkPos = attributePatternPos + attributePatternLen;
+    const QChar quotationMark = htmlCode[openingQuotationMarkPos];
+    if (quotationMark != QLatin1Char('"') && quotationMark != QLatin1Char('\'')) {
+        /// No valid opening quotation mark found
+        int spacePos = openingQuotationMarkPos;
+        while (spacePos < endPos && !htmlCode[spacePos].isSpace()) ++spacePos;
+        if (spacePos > endPos) return QString(); ///< no closing space found
+        return htmlCode.mid(openingQuotationMarkPos, spacePos - openingQuotationMarkPos);
+    } else {
+        /// Attribute has either single or double quotation marks
+        const int closingQuotationMarkPos = htmlCode.indexOf(quotationMark, openingQuotationMarkPos + 1);
+        if (closingQuotationMarkPos < 0 || closingQuotationMarkPos > endPos) return QString(); ///< closing quotation mark not found within limits
+        return htmlCode.mid(openingQuotationMarkPos + 1, closingQuotationMarkPos - openingQuotationMarkPos - 1);
+    }
+}
+
+bool OnlineSearchAbstract::htmlAttributeIsSelected(const QString &htmlCode, const int startPos, const QString &attribute) const
+{
+    const int endPos = htmlCode.indexOf(QLatin1Char('>'), startPos);
+    if (endPos < 0) return false; ///< no closing angle bracket found
+
+    const QString attributePattern = QStringLiteral(" ") + attribute;
+    const int attributePatternPos = htmlCode.indexOf(attributePattern, startPos, Qt::CaseInsensitive);
+    if (attributePatternPos < 0 || attributePatternPos > endPos) return false; ///< attribute not found within limits
+
+    const int attributePatternLen = attributePattern.length();
+    const QChar nextAfterAttributePattern = htmlCode[attributePatternPos + attributePatternLen];
+    if (nextAfterAttributePattern.isSpace() || nextAfterAttributePattern == QLatin1Char('>') || nextAfterAttributePattern == QLatin1Char('/'))
+        /// No value given for attribute (old-style HTML), so assuming it means checked/selected
+        return true;
+    else if (nextAfterAttributePattern == QLatin1Char('=')) {
+        /// Expecting value to attribute, so retrieve it and check for 'selected' or 'checked'
+        const QString attributeValue = htmlAttribute(htmlCode, attributePatternPos, attribute).toLower();
+        return attributeValue == QStringLiteral("selected") || attributeValue == QStringLiteral("checked");
+    }
+
+    /// Reaching this point only if HTML code is invalid
+    return false;
+}
+
 #ifdef HAVE_KF5
 /**
  * Display a passive notification popup using the D-Bus interface.
@@ -217,7 +284,7 @@ void OnlineSearchAbstract::sendVisualNotification(const QString &text, const QSt
         timeout = 10 * 1000;
 
     QDBusMessage m = QDBusMessage::createMethodCall(dbusServiceName, dbusPath, dbusInterfaceName, QStringLiteral("Notify"));
-    QList<QVariant> args = QList<QVariant>() << QStringLiteral("kdialog") << 0U << icon << title << text << QStringList() << QVariantMap() << timeout;
+    const QList<QVariant> args {QStringLiteral("kdialog"), 0U, icon, title, text, QStringList(), QVariantMap(), timeout};
     m.setArguments(args);
 
     QDBusMessage replyMsg = QDBusConnection::sessionBus().call(m);
@@ -252,18 +319,19 @@ QString OnlineSearchAbstract::encodeURL(QString rawText)
 
 QString OnlineSearchAbstract::decodeURL(QString rawText)
 {
-    static const QRegExp mimeRegExp("%([0-9A-Fa-f]{2})");
-    while (mimeRegExp.indexIn(rawText) >= 0) {
+    static const QRegularExpression mimeRegExp(QStringLiteral("%([0-9A-Fa-f]{2})"));
+    QRegularExpressionMatch mimeRegExpMatch;
+    while ((mimeRegExpMatch = mimeRegExp.match(rawText)).hasMatch()) {
         bool ok = false;
-        QChar c(mimeRegExp.cap(1).toInt(&ok, 16));
+        QChar c(mimeRegExpMatch.captured(1).toInt(&ok, 16));
         if (ok)
-            rawText = rawText.replace(mimeRegExp.cap(0), c);
+            rawText = rawText.replace(mimeRegExpMatch.captured(0), c);
     }
     rawText = rawText.replace(QStringLiteral("&amp;"), QStringLiteral("&")).replace(QLatin1Char('+'), QStringLiteral(" "));
     return rawText;
 }
 
-QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlText, int startPos)
+QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlText, int startPos) const
 {
     /// how to recognize HTML tags
     static const QString formTagEnd = QStringLiteral("</form>");
@@ -271,14 +339,6 @@ QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlT
     static const QString selectTagBegin = QStringLiteral("<select ");
     static const QString selectTagEnd = QStringLiteral("</select>");
     static const QString optionTagBegin = QStringLiteral("<option ");
-    /// regular expressions to test or retrieve attributes in HTML tags
-    static const QRegExp inputTypeRegExp("<input[^>]+\\btype=[\"]?([^\" >\n\t]*)", Qt::CaseInsensitive);
-    static const QRegExp inputNameRegExp("<input[^>]+\\bname=[\"]?([^\" >\n\t]*)", Qt::CaseInsensitive);
-    static const QRegExp inputValueRegExp("<input[^>]+\\bvalue=[\"]?([^\" >\n\t]*)", Qt::CaseInsensitive);
-    static const QRegExp inputIsCheckedRegExp("<input[^>]+\\bchecked([> \t\n]|=[\"]?checked)", Qt::CaseInsensitive);
-    static const QRegExp selectNameRegExp("<select[^>]+\\bname=[\"]?([^\" >\n\t]*)", Qt::CaseInsensitive);
-    static const QRegExp optionValueRegExp("<option[^>]+\\bvalue=[\"]?([^\" >\n\t]*)", Qt::CaseInsensitive);
-    static const QRegExp optionSelectedRegExp("<option[^>]* selected([> \t\n]|=[\"]?selected)", Qt::CaseInsensitive);
 
     /// initialize result map
     QMap<QString, QString> result;
@@ -294,9 +354,9 @@ QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlT
     int p = htmlText.indexOf(inputTagBegin, startPos, Qt::CaseInsensitive);
     while (p > startPos && p < endPos) {
         /// get "type", "name", and "value" attributes
-        QString inputType = inputTypeRegExp.indexIn(htmlText, p) == p ? inputTypeRegExp.cap(1).toLower() : QString();
-        QString inputName = inputNameRegExp.indexIn(htmlText, p) == p ? inputNameRegExp.cap(1) : QString();
-        QString inputValue = inputValueRegExp.indexIn(htmlText, p) ? inputValueRegExp.cap(1) : QString();
+        const QString inputType = htmlAttribute(htmlText, p, QStringLiteral("type")).toLower();
+        const QString inputName = htmlAttribute(htmlText, p, QStringLiteral("name"));
+        const QString inputValue = htmlAttribute(htmlText, p, QStringLiteral("value"));
 
         if (!inputName.isEmpty()) {
             /// get value of input types
@@ -304,12 +364,12 @@ QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlT
                 result[inputName] = inputValue;
             else if (inputType == QStringLiteral("radio")) {
                 /// must be selected
-                if (htmlText.indexOf(inputIsCheckedRegExp, p) == p) {
+                if (htmlAttributeIsSelected(htmlText, p, QStringLiteral("checked"))) {
                     result[inputName] = inputValue;
                 }
             } else if (inputType == QStringLiteral("checkbox")) {
                 /// must be checked
-                if (htmlText.indexOf(inputIsCheckedRegExp, p) == p) {
+                if (htmlAttributeIsSelected(htmlText, p, QStringLiteral("checked"))) {
                     /// multiple checkbox values with the same name are possible
                     result.insertMulti(inputName, inputValue);
                 }
@@ -324,17 +384,17 @@ QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlT
     p = htmlText.indexOf(selectTagBegin, startPos, Qt::CaseInsensitive);
     while (p > startPos && p < endPos) {
         /// get "name" attribute from "select" tag
-        const QString selectName = selectNameRegExp.indexIn(htmlText, p) == p ? selectNameRegExp.cap(1) : QString();
+        const QString selectName = htmlAttribute(htmlText, p, QStringLiteral("name"));
 
         /// "select" tag contains one or several "option" tags, search all
         int popt = htmlText.indexOf(optionTagBegin, p, Qt::CaseInsensitive);
         int endSelect = htmlText.indexOf(selectTagEnd, p, Qt::CaseInsensitive);
         while (popt > p && popt < endSelect) {
             /// get "value" attribute from "option" tag
-            const QString optionValue = optionValueRegExp.indexIn(htmlText, popt) == popt ? optionValueRegExp.cap(1) : QString();
+            const QString optionValue =  htmlAttribute(htmlText, popt, QStringLiteral("value"));
             if (!selectName.isEmpty() && !optionValue.isEmpty()) {
                 /// if this "option" tag is "selected", store value
-                if (htmlText.indexOf(optionSelectedRegExp, popt) == popt) {
+                if (htmlAttributeIsSelected(htmlText, popt, QStringLiteral("selected"))) {
                     result[selectName] = optionValue;
                 }
             }
@@ -348,6 +408,7 @@ QMap<QString, QString> OnlineSearchAbstract::formParameters(const QString &htmlT
     return result;
 }
 
+#ifdef HAVE_QTWIDGETS
 void OnlineSearchAbstract::iconDownloadFinished()
 {
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
@@ -370,7 +431,7 @@ void OnlineSearchAbstract::iconDownloadFinished()
         if (iconData.size() < 10) {
             /// Unlikely that an icon's data is less than 10 bytes,
             /// must be an error.
-            qCWarning(LOG_KBIBTEX_NETWORKING) << "Received invalid icon data from " << reply->url().toDisplayString();
+            qCWarning(LOG_KBIBTEX_NETWORKING) << "Received invalid icon data from " << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString();
             return;
         }
 
@@ -385,10 +446,10 @@ void OnlineSearchAbstract::iconDownloadFinished()
         } else if (iconData[0] == '<') {
             /// HTML or XML code
             const QString htmlCode = QString::fromUtf8(iconData);
-            qCDebug(LOG_KBIBTEX_NETWORKING) << "Received XML or HTML data from " << reply->url().toDisplayString() << ": " << htmlCode.left(128);
+            qCDebug(LOG_KBIBTEX_NETWORKING) << "Received XML or HTML data from " << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString() << ": " << htmlCode.left(128);
             return;
         } else {
-            qCWarning(LOG_KBIBTEX_NETWORKING) << "Favicon is of unknown format: " << reply->url().toDisplayString();
+            qCWarning(LOG_KBIBTEX_NETWORKING) << "Favicon is of unknown format: " << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString();
             return;
         }
         const QString filename = reply->objectName() + extension;
@@ -402,12 +463,13 @@ void OnlineSearchAbstract::iconDownloadFinished()
             if (listWidgetItem != nullptr)
                 listWidgetItem->setIcon(QIcon(filename));
         } else {
-            qCWarning(LOG_KBIBTEX_NETWORKING) << "Could not save icon data from URL" << reply->url().toDisplayString() << "to file" << filename;
+            qCWarning(LOG_KBIBTEX_NETWORKING) << "Could not save icon data from URL" << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString() << "to file" << filename;
             return;
         }
     } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "Could not download icon from URL " << reply->url().toDisplayString() << ": " << reply->errorString();
+        qCWarning(LOG_KBIBTEX_NETWORKING) << "Could not download icon from URL " << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString() << ": " << reply->errorString();
 }
+#endif // HAVE_QTWIDGETS
 
 void OnlineSearchAbstract::dumpToFile(const QString &filename, const QString &text)
 {
@@ -416,9 +478,7 @@ void OnlineSearchAbstract::dumpToFile(const QString &filename, const QString &te
     QFile f(usedFilename);
     if (f.open(QFile::WriteOnly)) {
         qCDebug(LOG_KBIBTEX_NETWORKING) << "Dumping text" << KBibTeX::squeezeText(text, 96) << "to" << usedFilename;
-        QTextStream ts(&f);
-        ts.setCodec("UTF-8");
-        ts << text;
+        f.write(text.toUtf8());
         f.close();
     }
 }
@@ -431,7 +491,6 @@ void OnlineSearchAbstract::delayedStoppedSearch(int returnCode)
 
 void OnlineSearchAbstract::delayedStoppedSearchTimer()
 {
-    emit progress(1, 1);
     stopSearch(m_delayedStoppedSearchReturnCode);
 }
 
@@ -446,7 +505,7 @@ void OnlineSearchAbstract::sanitizeEntry(QSharedPointer<Entry> entry)
     if (entry->type().isEmpty())
         entry->setType(Entry::etMisc);
 
-    const QString ftIssue = QStringLiteral("issue");
+    static const QString ftIssue = QStringLiteral("issue");
     if (entry->contains(ftIssue)) {
         /// ACM's Digital Library uses "issue" instead of "number" -> fix that
         Value v = entry->value(ftIssue);
@@ -456,7 +515,7 @@ void OnlineSearchAbstract::sanitizeEntry(QSharedPointer<Entry> entry)
 
     /// If entry contains a description field but no abstract,
     /// rename description field to abstract
-    const QString ftDescription = QStringLiteral("description");
+    static const QString ftDescription = QStringLiteral("description");
     if (!entry->contains(Entry::ftAbstract) && entry->contains(ftDescription)) {
         Value v = entry->value(ftDescription);
         entry->remove(ftDescription);
@@ -476,20 +535,76 @@ void OnlineSearchAbstract::sanitizeEntry(QSharedPointer<Entry> entry)
     }
 
     if (entry->contains(Entry::ftMonth)) {
-        /// Fix strigns for months: "September" -> "sep"
-        const QString monthStr = PlainTextValue::text(entry->value(Entry::ftMonth));
+        /// Fix strings for months: "September" -> "sep"
+        Value monthValue = entry->value(Entry::ftMonth);
+        bool updated = false;
+        for (Value::Iterator it = monthValue.begin(); it != monthValue.end(); ++it) {
+            const QString valueItem = PlainTextValue::text(*it);
 
-        static const QRegExp longMonth = QRegExp(QStringLiteral("(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)[a-z]*"), Qt::CaseInsensitive);
-        if (monthStr.indexOf(longMonth) == 0 && monthStr == longMonth.cap(0)) {
-            /// String used for month is actually a full name, therefore replace it
-            entry->remove(Entry::ftMonth);
+            static const QRegularExpression longMonth = QRegularExpression(QStringLiteral("(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)[a-z]*"), QRegularExpression::CaseInsensitiveOption);
+            const QRegularExpressionMatch longMonthMatch = longMonth.match(valueItem);
+            if (longMonthMatch.hasMatch()) {
+                it = monthValue.erase(it);
+                it = monthValue.insert(it, QSharedPointer<MacroKey>(new MacroKey(longMonthMatch.captured(1).toLower())));
+                updated = true;
+            }
+        }
+        if (updated)
+            entry->insert(Entry::ftMonth, monthValue);
+    }
 
-            /// Regular expression checked for valid three-letter abbreviations
-            /// that month names start with. Use those three letters for a macro key
-            /// Example: "September" -> sep
-            Value v;
-            v.append(QSharedPointer<MacroKey>(new MacroKey(longMonth.cap(1).toLower())));
-            entry->insert(Entry::ftMonth, v);
+    if (entry->contains(Entry::ftDOI) && entry->contains(Entry::ftUrl)) {
+        /// Remove URL from entry if contains a DOI and the DOI field matches the DOI in the URL
+        const Value &doiValue = entry->value(Entry::ftDOI);
+        for (const auto &doiValueItem : doiValue) {
+            const QString doi = PlainTextValue::text(doiValueItem);
+            Value v = entry->value(Entry::ftUrl);
+            bool gotChanged = false;
+            for (Value::Iterator it = v.begin(); it != v.end();) {
+                const QSharedPointer<ValueItem> &vi = (*it);
+                if (vi->containsPattern(QStringLiteral("/") + doi)) {
+                    it = v.erase(it);
+                    gotChanged = true;
+                } else
+                    ++it;
+            }
+            if (v.isEmpty())
+                entry->remove(Entry::ftUrl);
+            else if (gotChanged)
+                entry->insert(Entry::ftUrl, v);
+        }
+    } else if (!entry->contains(Entry::ftDOI) && entry->contains(Entry::ftUrl)) {
+        /// If URL looks like a DOI, remove URL and add a DOI field
+        QSet<QString> doiSet;
+        Value v = entry->value(Entry::ftUrl);
+        bool gotChanged = false;
+        for (Value::Iterator it = v.begin(); it != v.end();) {
+            const QString viText = PlainTextValue::text(*it);
+            const QRegularExpressionMatch doiRegExpMatch = KBibTeX::doiRegExp.match(viText);
+            if (doiRegExpMatch.hasMatch()) {
+                doiSet.insert(doiRegExpMatch.captured());
+                it = v.erase(it);
+                gotChanged = true;
+            } else
+                ++it;
+        }
+        if (v.isEmpty())
+            entry->remove(Entry::ftUrl);
+        else if (gotChanged)
+            entry->insert(Entry::ftUrl, v);
+        if (!doiSet.isEmpty()) {
+            Value doiValue;
+            for (const QString &doi : doiSet)
+                doiValue.append(QSharedPointer<PlainText>(new PlainText(doi)));
+            entry->insert(Entry::ftDOI, doiValue);
+        }
+    } else if (!entry->contains(Entry::ftDOI)) {
+        const QRegularExpressionMatch doiRegExpMatch = KBibTeX::doiRegExp.match(entry->id());
+        if (doiRegExpMatch.hasMatch()) {
+            /// If entry id looks like a DOI, add a DOI field
+            Value doiValue;
+            doiValue.append(QSharedPointer<PlainText>(new PlainText(doiRegExpMatch.captured())));
+            entry->insert(Entry::ftDOI, doiValue);
         }
     }
 
@@ -518,6 +633,7 @@ void OnlineSearchAbstract::stopSearch(int errorCode) {
         curStep = numSteps;
     else
         curStep = numSteps = 0;
+    emit progress(curStep, numSteps);
     emit stoppedSearch(errorCode);
 }
 
