@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,24 +12,25 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "onlinesearchgeneral.h"
 
+#ifdef HAVE_QTWIDGETS
 #include <QFormLayout>
 #include <QLabel>
 #include <QSpinBox>
 
 #include <KLineEdit>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KConfigGroup>
 
 #include "entry.h"
 
 OnlineSearchQueryFormGeneral::OnlineSearchQueryFormGeneral(QWidget *parent)
         : OnlineSearchQueryFormAbstract(parent),
-      configGroupName(QLatin1String("Search Engine General"))
+      configGroupName(QStringLiteral("Search Engine General"))
 {
     QFormLayout *layout = new QFormLayout(this);
     layout->setMargin(0);
@@ -37,35 +38,35 @@ OnlineSearchQueryFormGeneral::OnlineSearchQueryFormGeneral(QWidget *parent)
     QLabel *label = new QLabel(i18n("Free text:"), this);
     KLineEdit *lineEdit = new KLineEdit(this);
     layout->addRow(label, lineEdit);
-    lineEdit->setClearButtonShown(true);
+    lineEdit->setClearButtonEnabled(true);
     lineEdit->setFocus(Qt::TabFocusReason);
     queryFields.insert(OnlineSearchAbstract::queryKeyFreeText, lineEdit);
     label->setBuddy(lineEdit);
-    connect(lineEdit, SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
+    connect(lineEdit, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormGeneral::returnPressed);
 
     label = new QLabel(i18n("Title:"), this);
     lineEdit = new KLineEdit(this);
     layout->addRow(label, lineEdit);
-    lineEdit->setClearButtonShown(true);
+    lineEdit->setClearButtonEnabled(true);
     queryFields.insert(OnlineSearchAbstract::queryKeyTitle, lineEdit);
     label->setBuddy(lineEdit);
-    connect(lineEdit, SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
+    connect(lineEdit, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormGeneral::returnPressed);
 
     label = new QLabel(i18n("Author:"), this);
     lineEdit = new KLineEdit(this);
     layout->addRow(label, lineEdit);
-    lineEdit->setClearButtonShown(true);
+    lineEdit->setClearButtonEnabled(true);
     queryFields.insert(OnlineSearchAbstract::queryKeyAuthor, lineEdit);
     label->setBuddy(lineEdit);
-    connect(lineEdit, SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
+    connect(lineEdit, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormGeneral::returnPressed);
 
     label = new QLabel(i18n("Year:"), this);
     lineEdit = new KLineEdit(this);
     layout->addRow(label, lineEdit);
-    lineEdit->setClearButtonShown(true);
+    lineEdit->setClearButtonEnabled(true);
     queryFields.insert(OnlineSearchAbstract::queryKeyYear, lineEdit);
     label->setBuddy(lineEdit);
-    connect(lineEdit, SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
+    connect(lineEdit, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormGeneral::returnPressed);
 
     label = new QLabel(i18n("Number of Results:"), this);
     numResultsField = new QSpinBox(this);
@@ -89,9 +90,9 @@ bool OnlineSearchQueryFormGeneral::readyToStart() const
 
 void OnlineSearchQueryFormGeneral::copyFromEntry(const Entry &entry)
 {
-    queryFields[OnlineSearchAbstract::queryKeyFreeText]->setText("");
+    queryFields[OnlineSearchAbstract::queryKeyFreeText]->setText(PlainTextValue::text(entry[Entry::ftDOI]));
     queryFields[OnlineSearchAbstract::queryKeyTitle]->setText(PlainTextValue::text(entry[Entry::ftTitle]));
-    queryFields[OnlineSearchAbstract::queryKeyAuthor]->setText(authorLastNames(entry).join(" "));
+    queryFields[OnlineSearchAbstract::queryKeyAuthor]->setText(authorLastNames(entry).join(QStringLiteral(" ")));
     queryFields[OnlineSearchAbstract::queryKeyYear]->setText(PlainTextValue::text(entry[Entry::ftYear]));
 }
 
@@ -119,7 +120,7 @@ void OnlineSearchQueryFormGeneral::loadState()
     for (QMap<QString, KLineEdit *>::ConstIterator it = queryFields.constBegin(); it != queryFields.constEnd(); ++it) {
         it.value()->setText(configGroup.readEntry(it.key(), QString()));
     }
-    numResultsField->setValue(configGroup.readEntry(QLatin1String("numResults"), 10));
+    numResultsField->setValue(configGroup.readEntry(QStringLiteral("numResults"), 10));
 }
 
 void OnlineSearchQueryFormGeneral::saveState()
@@ -128,6 +129,7 @@ void OnlineSearchQueryFormGeneral::saveState()
     for (QMap<QString, KLineEdit *>::ConstIterator it = queryFields.constBegin(); it != queryFields.constEnd(); ++it) {
         configGroup.writeEntry(it.key(), it.value()->text());
     }
-    configGroup.writeEntry(QLatin1String("numResults"), numResultsField->value());
+    configGroup.writeEntry(QStringLiteral("numResults"), numResultsField->value());
     config->sync();
 }
+#endif // HAVE_QTWIDGETS
