@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,6 +21,8 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QUrlQuery>
+#include <QRegularExpression>
+#include <QRegularExpressionMatchIterator>
 
 #include <KLocalizedString>
 
@@ -39,7 +41,7 @@ public:
         bool hasFreeText = !query[queryKeyFreeText].isEmpty();
         bool hasTitle = !query[queryKeyTitle].isEmpty();
         bool hasAuthor = !query[queryKeyAuthor].isEmpty();
-        bool hasYear = QRegExp(QStringLiteral("^(19|20)[0-9]{2}$")).indexIn(query[queryKeyYear]) == 0;
+        bool hasYear = QRegularExpression(QStringLiteral("^(19|20)[0-9]{2}$")).match(query[queryKeyYear]).hasMatch();
 
         QString fieldWF = QStringLiteral("4BFF"); ///< search whole record by default
         QString fieldQ, fieldDB, fieldDE;
@@ -94,6 +96,8 @@ void OnlineSearchIDEASRePEc::startSearch(const QMap<QString, QString> &query, in
     QNetworkReply *reply = InternalNetworkAccessManager::instance().get(request);
     InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
     connect(reply, &QNetworkReply::finished, this, &OnlineSearchIDEASRePEc::downloadListDone);
+
+    refreshBusyProperty();
 }
 
 
@@ -137,19 +141,19 @@ void OnlineSearchIDEASRePEc::downloadListDone()
             d->publicationLinks.clear();
             if (ol1 > 0 && ol2 > ol1) {
                 const QString olHtmlCode = htmlCode.mid(ol1, ol2 - ol1 + 5);
-                static const QRegExp publicationLinkRegExp(QStringLiteral("\"/[a-z](/[^\"]+){1,6}[.]html"));
-                int p = -1;
-                while ((p = publicationLinkRegExp.indexIn(olHtmlCode, p + 1)) > 0) {
-                    const QUrl c = reply->url().resolved(QUrl(publicationLinkRegExp.cap().mid(1)));
+                static const QRegularExpression publicationLinkRegExp(QStringLiteral("\"/[a-z](/[^\"]+){1,6}[.]html"));
+                QRegularExpressionMatchIterator publicationLinkRegExpMatchIt = publicationLinkRegExp.globalMatch(olHtmlCode);
+                while (publicationLinkRegExpMatchIt.hasNext()) {
+                    const QRegularExpressionMatch publicationLinkRegExpMatch = publicationLinkRegExpMatchIt.next();
+                    const QUrl c = reply->url().resolved(QUrl(publicationLinkRegExpMatch.captured().mid(1)));
                     d->publicationLinks.insert(c);
                 }
                 numSteps += 2 * d->publicationLinks.count(); ///< update number of steps
             }
 
-            if (d->publicationLinks.isEmpty()) {
+            if (d->publicationLinks.isEmpty())
                 stopSearch(resultNoError);
-                emit progress(curStep = numSteps, numSteps);
-            } else {
+            else {
                 QSet<const QUrl>::Iterator it = d->publicationLinks.begin();
                 const QUrl publicationLink = *it;
                 d->publicationLinks.erase(it);
@@ -159,9 +163,9 @@ void OnlineSearchIDEASRePEc::downloadListDone()
                 connect(reply, &QNetworkReply::finished, this, &OnlineSearchIDEASRePEc::downloadPublicationDone);
             }
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
 
+    refreshBusyProperty();
 }
 
 void OnlineSearchIDEASRePEc::downloadPublicationDone()
@@ -199,9 +203,9 @@ void OnlineSearchIDEASRePEc::downloadPublicationDone()
         reply->setProperty("downloadurl", QVariant::fromValue<QString>(downloadUrl));
         InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
         connect(reply, &QNetworkReply::finished, this, &OnlineSearchIDEASRePEc::downloadBibTeXDone);
+    }
 
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    refreshBusyProperty();
 }
 
 void OnlineSearchIDEASRePEc::downloadBibTeXDone()
@@ -242,10 +246,9 @@ void OnlineSearchIDEASRePEc::downloadBibTeXDone()
             }
         }
 
-        if (d->publicationLinks.isEmpty()) {
+        if (d->publicationLinks.isEmpty())
             stopSearch(resultNoError);
-            emit progress(1, 1);
-        } else {
+        else {
             QSet<const QUrl>::Iterator it = d->publicationLinks.begin();
             const QUrl publicationLink = *it;
             d->publicationLinks.erase(it);
@@ -254,6 +257,7 @@ void OnlineSearchIDEASRePEc::downloadBibTeXDone()
             InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
             connect(reply, &QNetworkReply::finished, this, &OnlineSearchIDEASRePEc::downloadPublicationDone);
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString() << "(was" << downloadUrl << ")";
+    }
+
+    refreshBusyProperty();
 }
