@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,9 +20,12 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QUrlQuery>
+#include <QRegularExpression>
 
 #ifdef HAVE_KF5
 #include <KLocalizedString>
+#else // HAVE_KF5
+#define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
 #include "internalnetworkaccessmanager.h"
@@ -31,16 +34,13 @@
 
 class OnlineSearchJStor::OnlineSearchJStorPrivate
 {
-private:
-    // UNUSED OnlineSearchJStor *p;
-
 public:
     int numExpectedResults;
     static const QString jstorBaseUrl;
     QUrl queryUrl;
 
-    OnlineSearchJStorPrivate(OnlineSearchJStor */* UNUSED parent*/)
-        : /* UNUSED p(parent), */ numExpectedResults(0)
+    OnlineSearchJStorPrivate(OnlineSearchJStor *)
+            : numExpectedResults(0)
     {
         /// nothing
     }
@@ -72,8 +72,8 @@ void OnlineSearchJStor::startSearch(const QMap<QString, QString> &query, int num
     d->queryUrl.setPath(QStringLiteral("/action/doAdvancedSearch"));
     q.addQueryItem(QStringLiteral("Search"), QStringLiteral("Search"));
     q.addQueryItem(QStringLiteral("wc"), QStringLiteral("on")); /// include external references, too
-    q.addQueryItem(QStringLiteral("la"), QStringLiteral("")); /// no specific language
-    q.addQueryItem(QStringLiteral("jo"), QStringLiteral("")); /// no specific journal
+    q.addQueryItem(QStringLiteral("la"), QString()); /// no specific language
+    q.addQueryItem(QStringLiteral("jo"), QString()); /// no specific journal
     q.addQueryItem(QStringLiteral("hp"), QString::number(numResults)); /// hits per page
     int queryNumber = 0;
     const QStringList elementsTitle = splitRespectingQuotationMarks(query[queryKeyTitle]);
@@ -107,6 +107,8 @@ void OnlineSearchJStor::startSearch(const QMap<QString, QString> &query, int num
     QNetworkReply *reply = InternalNetworkAccessManager::instance().get(request);
     InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
     connect(reply, &QNetworkReply::finished, this, &OnlineSearchJStor::doneFetchingStartPage);
+
+    refreshBusyProperty();
 }
 
 QString OnlineSearchJStor::label() const
@@ -146,8 +148,9 @@ void OnlineSearchJStor::doneFetchingStartPage()
             InternalNetworkAccessManager::instance().setNetworkReplyTimeout(newReply);
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchJStor::doneFetchingResultPage);
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchJStor::doneFetchingResultPage()
@@ -162,9 +165,10 @@ void OnlineSearchJStor::doneFetchingResultPage()
 
         /// extract all unique DOI from HTML code
         QStringList uniqueDOIs;
-        int p = -6;
-        while ((p = KBibTeX::doiRegExp.indexIn(htmlText, p + 6)) >= 0) {
-            QString doi = KBibTeX::doiRegExp.cap(0);
+        QRegularExpressionMatchIterator doiRegExpMatchIt = KBibTeX::doiRegExp.globalMatch(htmlText);
+        while (doiRegExpMatchIt.hasNext()) {
+            const QRegularExpressionMatch doiRegExpMatch = doiRegExpMatchIt.next();
+            QString doi = doiRegExpMatch.captured(0);
             // FIXME DOI RegExp accepts DOIs with question marks, causes problems here
             const int p = doi.indexOf(QLatin1Char('?'));
             if (p > 0) doi = doi.left(p);
@@ -174,7 +178,6 @@ void OnlineSearchJStor::doneFetchingResultPage()
 
         if (uniqueDOIs.isEmpty()) {
             /// No results found
-            emit progress(curStep = numSteps, numSteps);
             stopSearch(resultNoError);
         } else {
             /// Build POST request that should return a BibTeX document
@@ -192,8 +195,9 @@ void OnlineSearchJStor::doneFetchingResultPage()
             InternalNetworkAccessManager::instance().setNetworkReplyTimeout(newReply);
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchJStor::doneFetchingBibTeXCode);
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchJStor::doneFetchingBibTeXCode()
@@ -218,20 +222,21 @@ void OnlineSearchJStor::doneFetchingBibTeXCode()
             delete bibtexFile;
         }
 
-        emit progress(curStep = numSteps, numSteps);
         stopSearch(numFoundResults > 0 ? resultNoError : resultUnspecifiedError);
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchJStor::sanitizeEntry(QSharedPointer<Entry> entry)
 {
     OnlineSearchAbstract::sanitizeEntry(entry);
 
-    if (KBibTeX::doiRegExp.indexIn(entry->id()) == 0) {
+    const QRegularExpressionMatch doiRegExpMatch = KBibTeX::doiRegExp.match(entry->id());
+    if (doiRegExpMatch.hasMatch()) {
         /// entry ID is a DOI
         Value v;
-        v.append(QSharedPointer<VerbatimText>(new VerbatimText(KBibTeX::doiRegExp.cap(0))));
+        v.append(QSharedPointer<VerbatimText>(new VerbatimText(doiRegExpMatch.captured(0))));
         entry->insert(Entry::ftDOI, v);
     }
 
