@@ -1,5 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *                 2018 Alexander Dunlap <alexander.dunlap@gmail.com>      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,6 +23,7 @@
 #include <QNetworkAccessManager>
 #include <QMap>
 #include <QUrlQuery>
+#include <QRegularExpression>
 
 #include <KLocalizedString>
 
@@ -32,9 +34,6 @@
 
 class OnlineSearchMathSciNet::OnlineSearchMathSciNetPrivate
 {
-private:
-    // UNUSED OnlineSearchMathSciNet *p;
-
 public:
     QMap<QString, QString> queryParameters;
     int numResults;
@@ -42,15 +41,15 @@ public:
     static const QString queryFormUrl;
     static const QString queryUrlStem;
 
-    OnlineSearchMathSciNetPrivate(OnlineSearchMathSciNet */* UNUSED parent*/)
-        : /* UNUSED p(parent), */ numResults(0)
+    OnlineSearchMathSciNetPrivate(OnlineSearchMathSciNet *parent)
+            : numResults(0)
     {
-        /// nothing
+        Q_UNUSED(parent)
     }
 };
 
-const QString OnlineSearchMathSciNet::OnlineSearchMathSciNetPrivate::queryFormUrl = QStringLiteral("http://www.ams.org/mathscinet/");
-const QString OnlineSearchMathSciNet::OnlineSearchMathSciNetPrivate::queryUrlStem = QStringLiteral("http://www.ams.org/mathscinet/search/publications.html?client=KBibTeX");
+const QString OnlineSearchMathSciNet::OnlineSearchMathSciNetPrivate::queryFormUrl = QStringLiteral("https://mathscinet.ams.org/mathscinet/");
+const QString OnlineSearchMathSciNet::OnlineSearchMathSciNetPrivate::queryUrlStem = QStringLiteral("https://mathscinet.ams.org/mathscinet/search/publications.html?client=KBibTeX");
 
 OnlineSearchMathSciNet::OnlineSearchMathSciNet(QWidget *parent)
         : OnlineSearchAbstract(parent), d(new OnlineSearchMathSciNetPrivate(this))
@@ -110,6 +109,8 @@ void OnlineSearchMathSciNet::startSearch(const QMap<QString, QString> &query, in
     QNetworkReply *reply = InternalNetworkAccessManager::instance().get(request);
     InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
     connect(reply, &QNetworkReply::finished, this, &OnlineSearchMathSciNet::doneFetchingQueryForm);
+
+    refreshBusyProperty();
 }
 
 QString OnlineSearchMathSciNet::label() const
@@ -124,7 +125,7 @@ QString OnlineSearchMathSciNet::favIconUrl() const
 
 QUrl OnlineSearchMathSciNet::homepage() const
 {
-    return QUrl(QStringLiteral("http://www.ams.org/mathscinet/help/about.html"));
+    return QUrl(QStringLiteral("https://mathscinet.ams.org/mathscinet/help/about.html"));
 }
 
 void OnlineSearchMathSciNet::doneFetchingQueryForm()
@@ -156,8 +157,9 @@ void OnlineSearchMathSciNet::doneFetchingQueryForm()
         QNetworkReply *newReply = InternalNetworkAccessManager::instance().get(request, reply);
         InternalNetworkAccessManager::instance().setNetworkReplyTimeout(newReply);
         connect(newReply, &QNetworkReply::finished, this, &OnlineSearchMathSciNet::doneFetchingResultPage);
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchMathSciNet::doneFetchingResultPage()
@@ -175,16 +177,18 @@ void OnlineSearchMathSciNet::doneFetchingResultPage()
         /// build url by appending parameters
         QUrl url(OnlineSearchMathSciNetPrivate::queryUrlStem);
         QUrlQuery query(url);
-        const QStringList copyParameters = QStringList() << QStringLiteral("foo") << QStringLiteral("reqargs") << QStringLiteral("batch_title");
+        static const QStringList copyParameters {QStringLiteral("foo"), QStringLiteral("bdl"), QStringLiteral("reqargs"), QStringLiteral("batch_title")};
         for (const QString &param : copyParameters) {
             query.addQueryItem(param, formParams[param]);
         }
         query.addQueryItem(QStringLiteral("fmt"), QStringLiteral("bibtex"));
 
-        int p = -1, count = 0;
-        static const QRegExp checkBoxRegExp(QStringLiteral("<input class=\"hlCheckBox\" type=\"checkbox\" name=\"b\" value=\"(\\d+)\""));
-        while (count < d->numResults && (p = checkBoxRegExp.indexIn(htmlText, p + 1)) >= 0) {
-            query.addQueryItem(QStringLiteral("b"), checkBoxRegExp.cap(1));
+        int count = 0;
+        static const QRegularExpression checkBoxRegExp(QStringLiteral("<input class=\"hlCheckBox\" type=\"checkbox\" name=\"b\" value=\"(\\d+)\""));
+        QRegularExpressionMatchIterator checkBoxRegExpMatchIt = checkBoxRegExp.globalMatch(htmlText);
+        while (count < d->numResults && checkBoxRegExpMatchIt.hasNext()) {
+            const QRegularExpressionMatch checkBoxRegExpMatch = checkBoxRegExpMatchIt.next();
+            query.addQueryItem(QStringLiteral("b"), checkBoxRegExpMatch.captured(1));
             ++count;
         }
 
@@ -197,11 +201,11 @@ void OnlineSearchMathSciNet::doneFetchingResultPage()
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchMathSciNet::doneFetchingBibTeXcode);
         } else {
             /// nothing found
-            emit progress(curStep = numSteps, numSteps);
             stopSearch(resultNoError);
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchMathSciNet::doneFetchingBibTeXcode()
@@ -235,12 +239,15 @@ void OnlineSearchMathSciNet::doneFetchingBibTeXcode()
         }
 
         stopSearch(hasEntry ? resultNoError : resultUnspecifiedError);
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchMathSciNet::sanitizeEntry(QSharedPointer<Entry> entry)
 {
+    OnlineSearchAbstract::sanitizeEntry(entry);
+
     const QString ftFJournal = QStringLiteral("fjournal");
     if (entry->contains(ftFJournal)) {
         Value v = entry->value(ftFJournal);
