@@ -34,7 +34,6 @@
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <KLocalizedString>
-#include <KSharedConfig>
 #include <KMessageBox>
 
 #include "kbibtex.h"
@@ -253,13 +252,6 @@ KBibTeXMainWindow::KBibTeXMainWindow(QWidget *parent)
 {
     setObjectName(QStringLiteral("KBibTeXShell"));
 
-    /*
-        const char mainWindowStateKey[] = "State";
-        KConfigGroup group( KSharedConfig::openConfig(), "MainWindow" );
-        if( !group.hasKey(mainWindowStateKey) )
-            group.writeEntry( mainWindowStateKey, mainWindowState );
-    */
-
     setXMLFile(QStringLiteral("kbibtexui.rc"));
 
     setCentralWidget(d->mdiWidget);
